#ifndef FEOPTSGEN_H
#define FEOPTSGEN_H
/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/
/*
* ABSTRACT: Declarations for working with Options
*/

#include "Singular/fegetopt.h"

extern const char SHORT_OPTS_STRING[];

#include "Singular/feOptTab.h"
typedef enum {FE_OPT_UNDEF}  feOptIndex;

#endif /*  FEOPTSGEN_H */
